#delim ;
version 7.0;
*
 Examples for Stata user group presentation
 (uses the -split- program downloadable from SSC)
*;

use auto,clear;

* Create gallons per mile *;
gene gpm=1/mpg;
lab var gpm "Fuel consumption (gallons/mile)";
summ gpm;
gene wmpm=gpm*8*2*6;
lab var wmpm "Fuel consumption (whisky measures/mile)";
gene tons=weight/2240;
lab var tons "Weight (tons)";

* Create variables for manufacturer, model and country of origin *;
gene byte us=!foreign;
lab var us "US origin";
split make,gene(s_);
rename s_1 manuf;rename s_2 model;
lab var manuf "Manufacturer";lab var model "Model";
tab manuf,m;
gene country=1 if !foreign;
replace country=2 if inlist(manuf,"Audi","BMW","Merc.","VW");
replace country=3 if inlist(manuf,"Datsun","Honda","Mazda","Subaru");
replace country=3 if inlist(manuf,"Toyota");
replace country=4 if inlist(manuf,"Peugeot","Renault");
replace country=5 if inlist(manuf,"Fiat");
replace country=6 if inlist(manuf,"Volvo");
compress country;
lab def country 1 "US" 2 "Germany" 3 "Japan" 4 "France" 5 "Italy" 6 "Sweden";
lab var country "Country of origin";
lab val country country;
char country[omit] 1;
tab country,m;
tab manuf country,m;

xi i.country;
desc _I*;

set textsize 150;

* Scatter plot *;
grap wmpm wmpm tons,xlab ylab s(T[country])
 t1(" ") l1("Fuel consumption (whisky measures/mile)");
translate @Graph fig1.eps,replace;
more;

* Single analysis, described and listed *;
preserve;
parmby "xi:regress wmpm tons i.country,nohead",label;
format estimate min95 max95 %8.2f;
describe;
list parm label estimate min95 max95,noobs;
restore;

* Single analysis, plotted using -descsave- and -factext- *;
preserve;
tempfile tf0;
descsave country,do(`tf0');
parmby "xi:regress wmpm tons i.country,nohead",label;
factext,do(`tf0');
format estimate min95 max95 %8.2f;
list parm label country estimate min95 max95,noobs;
grap estimate min95 max95 country,
 xsc(1,7) xlab(2(1)6) ylab ylin(0) s(O..) c(.II)
 t1("Fuel use compared to US cars of same weight")
 l1("Difference (whisky measures/mile)");
more;
translate @Graph fig2.eps,replace;
restore;

* Multiple analyses, using -idstr-, -idnum- and -dsconcat- *;
preserve;
tempfile tf1 tf2 tf3;
parmby "regress wmpm tons,nohead",label idnum(1) idstr(Unadj.)
 saving(`tf1',replace);
parmby "regress wmpm us,nohead",label idnum(2) idstr(Unadj.)
 saving(`tf2',replace);
parmby "regress wmpm tons us,nohead",label idnum(3) idstr(Adj.)
 saving(`tf3',replace);
dsconcat `tf1' `tf2' `tf3';
format estimate min95 max95 %8.2f;
sort idnum idstr parmseq;
by idnum idstr:list parm label estimate min95 max95,noobs;
sencode idstr,gene(anatype);
lab var anatype "Analysis type";
drop if parm=="_cons";
sencode label,gene(predictor);
lab var predictor "Predictor variable";
sort predictor anatype;
grap estimate min95 max95 anatype,xsc(0 3) xlab(1 2) ylab ylin(0) s(O..) c(.II) by(predictor)
 t1("Effects of weight and US origin on fuel consumption")
 l1("Difference (whisky measures/mile)");
more;
translate @Graph fig3.eps,replace;
restore;


exit;
